﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class AdminMenu_BoardInfo_BoardList : System.Web.UI.Page
{
    private OleDbConnection Con;
    private OleDbDataAdapter Adap;
    private OleDbTransaction Trans;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter sParams = new OleDbParameter();
    private DataSet ds = new DataSet();
    private DataTable dt = new DataTable();
    private WebFunction WF;
    private UserInfo UI;

    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private int iPage = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../../log/login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        UI = new UserInfo(Session["USER_ID"].ToString(), strDomain, strCon);

        // 권한 체크
        // 권한이 1이 아니면 메인화면으로 페이지를 이동시킨다.
        if (UI.UserPermit != "1")
        {
            WF.WriteMessage("여기는 웹메일 관리자만 접근할 수 있는 페이지 입니다.");
            Response.Redirect("../../Mail/Main.aspx");
        }


        iPage = WF.StringToInt(Request.Params["iPage"], 1);

        if (!Page.IsPostBack)
        {
            this.BoardDataBind();
        }
    }

    #region 게시판 리스트 데이터를 바인드 한다.
    /// <summary>
    /// 게시판 리스트 데이터를 바인드 한다.
    /// </summary>
    private void BoardDataBind()
    {
        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("../default.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prBoardList";

            Cmd.Parameters.Clear();

            // 페이지 파라미터 설정
            sParams = Cmd.Parameters.Add("@iPage", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 페이지 사이즈 파라미터 설정
            sParams = Cmd.Parameters.Add("@iPageSize", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 도메인 파라미터 설정
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // 각 파라미터에 값 입력
            Cmd.Parameters["@iPage"].Value = iPage;
            Cmd.Parameters["@iPageSize"].Value = 15;
            Cmd.Parameters["@varDomain"].Value = strDomain;

            Adap = new OleDbDataAdapter(Cmd);

            Adap.Fill(ds, "BRD_INFO");
            dt = ds.Tables["BRD_INFO"];

            int iRowCnt = dt.Rows.Count;
            int iCnt = 0;
            string[,] arrBoardInfo = new string[iRowCnt, 7];

            foreach (DataRow dr in dt.Rows)
            {
                // 게시판 번호
                int iBrdNo = Math.Abs(int.Parse(dr["BRD_NO"].ToString(), System.Globalization.NumberStyles.Number));
                // 게시판 보기 번호
                int iBrdViewNo = Math.Abs(int.Parse(dr["BRD_VIEW_NO"].ToString(), System.Globalization.NumberStyles.Number));
                // 게시판 게시물 수
                int iBrdDocCnt = Math.Abs(int.Parse(dr["BRD_DOC_CNT"].ToString(), System.Globalization.NumberStyles.Number));

                arrBoardInfo[iCnt, 0] = iBrdNo.ToString();					// 게시판 고유번호
                arrBoardInfo[iCnt, 1] = iBrdViewNo.ToString();				// 게시판 번호
                arrBoardInfo[iCnt, 2] = dr["BRD_NAME"].ToString();			// 게시판 명
                arrBoardInfo[iCnt, 3] = iBrdDocCnt.ToString();				// 출력 게시물수
                arrBoardInfo[iCnt, 4] = dr["BRD_IS_ATTACH"].ToString();		// 첨부파일 사용여부
                arrBoardInfo[iCnt, 5] = dr["BRD_ADMIN_ID"].ToString();		// 게시판 관리자 아이디
                arrBoardInfo[iCnt, 6] = dr["BRD_CREATE_DATE"].ToString();	// 게시판 생성일자
                ++iCnt;
            }

            dt.Clear();

            for (int iLoop = 0; iLoop < iCnt; iLoop++)
            {
                DataRow dr = dt.NewRow();
                dr["BRD_NO"] = arrBoardInfo[iLoop, 0];
                dr["BRD_VIEW_NO"] = arrBoardInfo[iLoop, 1];
                // 게시판 이동 링크
                dr["BRD_NAME"] = "<a href=\"../../Board/ListDoc.aspx?brdNo=" + arrBoardInfo[iLoop, 0] + "\">" + arrBoardInfo[iLoop, 2] + "</a>";
                dr["BRD_DOC_CNT"] = arrBoardInfo[iLoop, 3];

                // 첨부파일 사용여부
                if (arrBoardInfo[iLoop, 4].ToString() == "Y")
                    dr["BRD_IS_ATTACH"] = "사용";
                else
                    dr["BRD_IS_ATTACH"] = "미사용";

                dr["BRD_ADMIN_ID"] = arrBoardInfo[iLoop, 5];
                dr["BRD_CREATE_DATE"] = arrBoardInfo[iLoop, 6];
                dt.Rows.Add(dr);
            }

        }
        catch (Exception err)
        {
            WF.WriteMessage("게시판 리스트를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            return;
        }
        finally
        {
            Con.Close();
        }

        rptBoardList.DataSource = dt.DefaultView;
        rptBoardList.DataBind();
    }
    #endregion

    #region 게시판 수정 페이지로 이동
    /// <summary>
    /// 게시판 수정 페이지로 이동
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibModifyBoard_ModifyCommand(object sender, System.Web.UI.WebControls.CommandEventArgs e)
    {
        string strBrdNo = e.CommandArgument.ToString();

        WF.MovePage("ModifyBoard.aspx?brdNo=" + strBrdNo);
    }
    #endregion

    #region 게시판 삭제
    /// <summary>
    /// 게시판 삭제
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibDeleteBoard_DeleteCommand(object sender, System.Web.UI.WebControls.CommandEventArgs e)
    {
        string strBrdNo = e.CommandArgument.ToString();
        string strRtnVal = "";

        if (strBrdNo != "" && strBrdNo != null)
        {
            try
            {
                Con = new OleDbConnection(strCon);
                Con.Open();
                Trans = Con.BeginTransaction();
            }
            catch (Exception err)
            {
                WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                    err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
                WF.MovePage("BoardList.aspx");
                return;
            }

            try
            {
                Cmd.Connection = Con;
                Cmd.Transaction = Trans;
                Cmd.CommandType = CommandType.StoredProcedure;
                Cmd.CommandText = "prDeleteBoard";

                Cmd.Parameters.Clear();

                // 실행 결과값
                sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
                sParams.Direction = ParameterDirection.ReturnValue;

                // 게시판 고유번호
                sParams = Cmd.Parameters.Add("@iBrdNo", OleDbType.Integer);
                sParams.Direction = ParameterDirection.Input;

                // 도메인명
                sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
                sParams.Direction = ParameterDirection.Input;

                // 리턴값
                sParams = Cmd.Parameters.Add("@varRtnVal", OleDbType.VarChar, 100);
                sParams.Direction = ParameterDirection.Output;

                Cmd.Parameters["@iBrdNo"].Value = int.Parse(strBrdNo);
                Cmd.Parameters["@varDomain"].Value = strDomain;

                Cmd.ExecuteNonQuery();

                int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());
                strRtnVal = Cmd.Parameters["@varRtnVal"].Value.ToString();

                if (iValue == -1)
                {
                    Trans.Rollback();
                    WF.WriteMessage(strRtnVal.Replace("\r\n", "\\r\\n"));
                    return;
                }
                else if (iValue != 0)
                {
                    Trans.Rollback();
                    WF.WriteMessage("게시판을 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                        "SQL Error No: " + iValue.ToString());
                    return;
                }

                Trans.Commit();
            }
            catch (Exception err)
            {
                Trans.Rollback();
                WF.WriteMessage("게시판을 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
                return;
            }
            finally
            {
                // 게시판이 첨부파일 사용이면 폴더가 존재하는지 확인하고 존재하지 않으면
                // 폴더를 생성한다.
                if (strRtnVal.ToUpper() == "Y")
                {
                    string strBrdPath = Request.PhysicalApplicationPath;

                    strBrdPath += "\\Board\\Data\\" + strBrdNo;

                    if (Directory.Exists(strBrdPath))
                        Directory.Delete(strBrdPath, true);
                }
                
                Con.Close();
            }

            WF.WriteMessage("게시판을 삭제했습니다.\\r\\n\\r\\n삭제된 게시판 고유번호: " + strBrdNo);
            WF.MovePage("BoardList.aspx");
            return;
        }
        else
        {
            WF.WriteMessage("게시판 고유번호가 없습니다.");
            return;
        }
    }
    #endregion

    #region Repeater 컨트롤 아이템 데이터 바운드
    /// <summary>
    /// Repeater 컨트롤에 바운드 되는 ImageButton에 onclick 속성을 추가한다.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void rptBoardList_ItemDataBound(object sender, System.Web.UI.WebControls.RepeaterItemEventArgs e)
    {
        string strDeleteScript = "if (confirm('해당 게시판을 삭제하겠습니까?\\r\\n\\r\\n삭제하게 되면 데이터는 복구할 수 없습니다.')) return true; else return false;";
        int iItmCnt = e.Item.Controls.Count;

        for (int iCnt = 0; iCnt < iItmCnt; iCnt++)
        {
            // 게시판 삭제 ImageButton
            ImageButton ibDelete = (ImageButton)e.Item.Controls[iCnt].FindControl("ibDeleteBoard");

            // 게시판 삭제 ImageButton 객체가 정의되어 있을때
            // 클라이언트 onclick 이벤트를 넣는다.
            if (ibDelete != null)
            {
                // 데모
                //strDeleteScript = "alert('데모라서 게시판을 삭제할 수 없습니다.'); return false;";
                ibDelete.Attributes.Add("onclick", strDeleteScript);
            }
        }
    }
    #endregion
}
