﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class AdminMenu_DomainConfig_AddDomain : System.Web.UI.Page
{
    private OleDbConnection Con;
    private OleDbTransaction Trans;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter sParams = new OleDbParameter();
    private DataTable dt = new DataTable();
    private DataSet ds = new DataSet();
    private WebFunction WF;

    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain;
    private string strSql;
    private string tblMailUser;
    private string fldUserId;

    protected void Page_Load(object sender, EventArgs e)
    {
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../../Log/Login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        UserInfo UI = new UserInfo(Session["USER_ID"].ToString(), strDomain, strCon);

        if (UI.UserPermit != "1")
        {
            WF.WriteMessage("여기는 웹메일 관리자만 접근할 수 있는 페이지 입니다.");
            Response.Redirect("../../Mail/Main.aspx");
            return;
        }

        if (Passkorea.Configuration.GetConfigField("serverinfo", "root_domain") != strDomain)
        {
            WF.WriteMessage("여기는 전체 관리자만 접근할 수 있는 페이지 입니다.");
            Response.Redirect("../Default.aspx");
            return;
        }
    }

    protected void btnAddomain_Click(object sender, EventArgs e)
    {
        string strDomain = tbDomain.Text;
        string strAllocateSize = tbAllocateSize.Text;
        string strUserCount = tbUserCount.Text;
        string strDefaultSize = tbDefaultSize.Text;
        string strJoinType = rblJoinType.SelectedValue;
        string strPop3Allow = rblPop3Allow.SelectedValue;
        string strCopyright = tbCopyright.Text;

        if (strDomain.Trim() == "")
        {
            WF.WriteMessage("도메인이 입력되지 않았습니다.");
            WF.HistoryBack();
        }

        if (strAllocateSize.Trim() == "")
        {
            WF.WriteMessage("할당용량을 입력해 주세요.");
            WF.HistoryBack();
        }

        if (strUserCount.Trim() == "")
        {
            WF.WriteMessage("사용자 할당수를 입력해 주세요.");
            WF.HistoryBack();
        }

        if (strDefaultSize.Trim() == "")
        {
            WF.WriteMessage("가입시 기본용량을 입력해 주세요.");
            WF.HistoryBack();
        }

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
            Trans = Con.BeginTransaction();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.HistoryBack();
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.Transaction = Trans;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prAddDomain";

            sParams = Cmd.Parameters.Add("@iResult", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            sParams = Cmd.Parameters.Add("@strDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@iAllocateSize", OleDbType.Integer, strAllocateSize.Length);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@iUserCount", OleDbType.Integer, strUserCount.Length);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@strJoinType", OleDbType.Char, 1);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@iDefaultSize", OleDbType.Integer, strDefaultSize.Length);
            sParams.Direction = ParameterDirection.Input;
            
            sParams = Cmd.Parameters.Add("@strPop3Allow", OleDbType.Char, 1);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@strCopyright", OleDbType.VarWChar, strCopyright.Length);
            sParams.Direction = ParameterDirection.Input;

            sParams = Cmd.Parameters.Add("@strReturnValue", OleDbType.VarChar, 600);
            sParams.Direction = ParameterDirection.Output;

            Cmd.Parameters["@strDomain"].Value = strDomain;
            Cmd.Parameters["@iAllocateSize"].Value = int.Parse(strAllocateSize);
            Cmd.Parameters["@iUserCount"].Value = int.Parse(strUserCount);
            Cmd.Parameters["@strJoinType"].Value = strJoinType;
            Cmd.Parameters["@iDefaultSize"].Value = int.Parse(strDefaultSize);
            Cmd.Parameters["@strPop3Allow"].Value = strPop3Allow;
            Cmd.Parameters["@strCopyright"].Value = strCopyright;

            Cmd.ExecuteNonQuery();

            int iResult = int.Parse(Cmd.Parameters["@iResult"].Value.ToString());

            if (iResult != 0)
            {
                Trans.Rollback();
                WF.WriteMessage(Cmd.Parameters["@strReturnValue"].Value.ToString().Replace("\r\n", "\\r\\n"));
                WF.HistoryBack();
                return;
            }

            // 도메인이 DB에 저장되었으면 list.txt에도 정보를 추가해 줘야 한다.
            if (!Passkorea.Configuration.AddDomain(strDomain))
            {
                Trans.Rollback();
                WF.WriteMessage(Passkorea.Configuration.GetErrorMessage);
                WF.HistoryBack();
                return;
            }

            Trans.Commit();
        }
        catch (Exception err)
        {
            Trans.Rollback();
            WF.WriteMessage(err.Message.Replace("\r\n", "\\r\\n"));
            WF.HistoryBack();
        }
        finally
        {
            Con.Close();
        }

        WF.WriteMessage(strDomain + " 도메인이 정상적으로 추가되었습니다.\\r\\n추가된 도메인을 사용하려면 nWmail 서버 관리툴을 띄워서 메일서비스를 재시작해야 합니다.");
        WF.MovePage("DomainLIst.aspx");
    }
}
