﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class AdminMenu_MailAddress_ControlCommonGroup : System.Web.UI.Page
{
    private OleDbConnection Con;
    private OleDbTransaction Trans;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter sParams = new OleDbParameter();
    private OleDbDataAdapter Adap;
    private DataSet ds = new DataSet();
    private DataTable dt = new DataTable();
    private WebFunction WF;
    private UserInfo UI;
    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strUserId = "";
    protected string strGroupName = "";
    protected int iGroupUserCount = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../../Log/Login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        UI = new UserInfo(Session["USER_ID"].ToString(), strDomain, strCon);

        if (UI.UserPermit != "1")
        {
            WF.WriteMessage("여기는 웹메일 관리자만 접근할 수 있는 페이지 입니다.");
            WF.MovePage("../../Mail/Main.aspx");
            return;
        }

        strUserId = Session["USER_ID"].ToString();

        if (!Page.IsPostBack)
        {
            this.GroupListDataBind();

            for (int iLoop = 0; iLoop < rptGroupList.Items.Count; iLoop++)
            {
                ImageButton btn = (ImageButton)rptGroupList.Items[iLoop].FindControl("ibDelGroup");

                if (btn.CommandArgument.ToString() == "")
                {
                    btn.Visible = false;
                    break;
                }
            }
        }

        ibAddGroup.Attributes.Add("onclick", "if (!AddGroup()) return false; else return true;");
    }

    #region 그룹 데이터 바인드
    /// <summary>
    /// 그룹 데이터 바인드
    /// </summary>
    private void GroupListDataBind()
    {
        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ListAddrInfo.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListGroup";

            Cmd.Parameters.Clear();

            // Command Parameter (User Id)
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Domain)
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Common)
            sParams = Cmd.Parameters.Add("@chrCommon", OleDbType.Char, 1);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Null Group Email Count)
            sParams = Cmd.Parameters.Add("@iNullGroup", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Output;

            Cmd.Parameters["@varUserId"].Value = strUserId;
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@chrCommon"].Value = "Y";

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "MAIL_GROUP");
            dt = ds.Tables["MAIL_GROUP"];

            int iNullGrpCnt = int.Parse(Cmd.Parameters["@iNullGroup"].Value.ToString());
            int iRowCnt = dt.Rows.Count;

            string[,] arrGroupInfo = new string[iRowCnt, 5];

            for (int iLoop = 0; iLoop < iRowCnt; iLoop++)
            {
                arrGroupInfo[iLoop, 0] = dt.Rows[iLoop]["GROUP_NAME"].ToString();
                arrGroupInfo[iLoop, 1] = dt.Rows[iLoop]["GROUP_NAME"].ToString();
                arrGroupInfo[iLoop, 2] = dt.Rows[iLoop]["GROUP_DESC"].ToString();
                arrGroupInfo[iLoop, 3] = dt.Rows[iLoop]["EMAIL_COUNT"].ToString();
                arrGroupInfo[iLoop, 4] = dt.Rows[iLoop]["IS_COMMON"].ToString();
            }

            dt.Clear();

            dt.Columns.Add("GROUP_VALUE", System.Type.GetType("System.String"));

            for (int iLoop = 0; iLoop < iRowCnt; iLoop++)
            {
                DataRow dr = dt.NewRow();
                dr["GROUP_NAME"] = arrGroupInfo[iLoop, 0];
                dr["GROUP_DESC"] = arrGroupInfo[iLoop, 2];
                dr["EMAIL_COUNT"] = arrGroupInfo[iLoop, 3];

                // 미지정 그룹이 아닐때 그룹값에 공유 여부값을 포함해서 값을 설정한다.
                if (arrGroupInfo[iLoop, 1] != "")
                    dr["GROUP_VALUE"] = arrGroupInfo[iLoop, 1] + "│" + arrGroupInfo[iLoop, 4];

                dt.Rows.Add(dr);
            }
        }
        catch (Exception err)
        {
            WF.WriteMessage("그룹 리스트를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("../Default.aspx");
            return;
        }
        finally
        {
            Con.Close();
        }

        rptGroupList.DataSource = dt.DefaultView;
        rptGroupList.DataBind();
    }
    #endregion

    #region 공유 그룹 추가 버튼
    /// <summary>
    /// 공유 그룹 추가 버튼
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibAddGroup_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        string strGroupName = tbGroupName.Text;
        string strGroupDesc = tbGroupDesc.Text;

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
            Trans = Con.BeginTransaction();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ControlGroup.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.Transaction = Trans;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prInsertGroup";

            Cmd.Parameters.Clear();

            // Command Parameter (Execute Return Value)
            sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // Command Parameter (User Id)
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Domain)
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Group Name)
            sParams = Cmd.Parameters.Add("@varGroupName", OleDbType.VarWChar, strGroupName.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Group Description)
            sParams = Cmd.Parameters.Add("@varGroupDesc", OleDbType.VarWChar, strGroupDesc.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Common)
            sParams = Cmd.Parameters.Add("@chrCommon", OleDbType.Char, 1);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Output Value)
            sParams = Cmd.Parameters.Add("@varRtnVal", OleDbType.VarChar, 200);
            sParams.Direction = ParameterDirection.Output;

            Cmd.Parameters["@varUserId"].Value = Session["USER_ID"].ToString();
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@varGroupName"].Value = strGroupName;
            Cmd.Parameters["@varGroupDesc"].Value = strGroupDesc;
            Cmd.Parameters["@chrCommon"].Value = "Y";

            Cmd.ExecuteNonQuery();

            int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());

            if (iValue < 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage(strGroupName + " 공유 그룹을 등록하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "오류 내용: " + Cmd.Parameters["@varRtnVal"].Value.ToString().Replace("\r\n", "\\r\\n"));
                WF.MovePage("ControlCommonGroup.aspx");
                return;
            }
            else if (iValue != 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage(strGroupName + " 공유 그룹을 등록하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "SQL Error Number: " + iValue.ToString());
                WF.MovePage("ControlCommonGroup.aspx");
                return;
            }
            
            Trans.Commit();
        }
        catch (Exception err)
        {
            Trans.Rollback();
            Con.Close();

            WF.WriteMessage(strGroupName + " 공유 그룹을 등록하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ControlCommonGroup.aspx");
            return;
        }
        finally
        {
            Con.Close();
        }

        WF.WriteMessage(strGroupName + " 공유 그룹이 등록되었습니다.");
        WF.MovePage("ControlCommonGroup.aspx");
    }
    #endregion

    #region 공유 그룹 삭제 버튼
    /// <summary>
    /// 공유 그룹 삭제 버튼
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibDelGroup_DeleteCommand(object sender, System.Web.UI.WebControls.CommandEventArgs e)
    {
        string strGroupName = e.CommandArgument.ToString();
        string isCommon = "";

        if (strGroupName == "")
        {
            WF.WriteMessage("삭제할 공유 그룹 이름이 없습니다.");
            return;
        }

        int iPos = 0;
        iPos = strGroupName.IndexOf("│");

        if (iPos > 0)
        {
            isCommon = strGroupName.Substring(iPos + 1, 1);
            strGroupName = strGroupName.Substring(0, iPos);
        }

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
            Trans = Con.BeginTransaction();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ControlGroup.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.Transaction = Trans;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prDeleteGroup";

            Cmd.Parameters.Clear();

            // Command Parameter (Execute Return Value)
            sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // Command Parameter (User Id)
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Domain)
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Group Name)
            sParams = Cmd.Parameters.Add("@varGroupName", OleDbType.VarWChar, strGroupName.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Common)
            sParams = Cmd.Parameters.Add("@chrCommon", OleDbType.Char, 1);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@varUserId"].Value = Session["USER_ID"].ToString();
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@varGroupName"].Value = strGroupName;
            Cmd.Parameters["@chrCommon"].Value = isCommon;

            Cmd.ExecuteNonQuery();

            int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());

            if (iValue != 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage(strGroupName + " 공유 그룹을 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "SQL Error Number: " + iValue.ToString());
                WF.MovePage("ControlCommonGroup.aspx");
                return;
            }

            Trans.Commit();
        }
        catch (Exception err)
        {
            Trans.Rollback();
            Con.Close();

            WF.WriteMessage(strGroupName + " 공유 그룹을 등록하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ControlCommonGroup.aspx");
            return;
        }
        finally
        {
            Con.Close();
        }

        WF.WriteMessage(strGroupName + " 공유 그룹을 삭제하였습니다.");
        WF.MovePage("ControlCommonGroup.aspx");
    }
    #endregion
}
