﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class AdminMenu_Schedule_MonthSchedule : System.Web.UI.Page
{
    protected int iNextYear;
    protected int iPrevYear;
    protected int iNextMonth;
    protected int iPrevMonth;

    private WebFunction WF;
    private UserInfo UI;
    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strUserId = "";
    private string strYear = "";
    private string strMonth = "";
    private int iYear = 0;
    private int iMonth = 0;
    private string[] arrScheduleData = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../../Log/Login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strUserId = Session["USER_ID"].ToString();
        UI = new UserInfo(strUserId, strDomain, strCon);

        if (UI.UserPermit != "1")
        {
            WF.WriteMessage("여기는 웹메일 관리자만 접근할 수 있는 페이지 입니다.");
            Response.Redirect("../../Mail/Main.aspx");
        }

        strYear = Request.Params["strYear"];
        strMonth = Request.Params["strMonth"];

        
        if ((strYear != "" && strYear != null) && (strMonth != "" && strMonth != null))
        {
            iYear = int.Parse(strYear, System.Globalization.NumberStyles.Number);
            iMonth = int.Parse(strMonth, System.Globalization.NumberStyles.Number);

            Calendar.VisibleDate = new DateTime(iYear, iMonth, 1);
        }
        else
            Calendar.SelectedDate = DateTime.Now;

        if (strYear == "" || strYear == null)
        {
            strYear = Calendar.SelectedDate.Year.ToString();
            iYear = int.Parse(strYear, System.Globalization.NumberStyles.Number);
        }

        if (strMonth == "" || strMonth == null)
        {
            strMonth = Calendar.SelectedDate.Month.ToString();
            iMonth = int.Parse(strMonth, System.Globalization.NumberStyles.Number);
        }

        if (iMonth == 12)
        {
            iNextYear = iYear + 1;
            iNextMonth = 1;
            iPrevYear = iYear;
            iPrevMonth = iMonth - 1;
        }
        else if (iMonth == 1)
        {
            iNextYear = iYear;
            iNextMonth = iMonth + 1;
            iPrevYear = iYear - 1;
            iPrevMonth = 12;
        }
        else
        {
            iNextYear = iYear;
            iNextMonth = iMonth + 1;
            iPrevYear = iYear;
            iPrevMonth = iMonth - 1;
        }

        // 배열을 생성한다.
        // 배열 길이는 현재달의 마지막 날짜까지로 한다.
        arrScheduleData = new string[WF.GetLastDay(int.Parse(strYear), int.Parse(strMonth)) + 1];

        // 배열 초기화
        for (int iLoop = 0; iLoop < arrScheduleData.Length; iLoop++)
            arrScheduleData[iLoop] = "";

        if (!Page.IsPostBack)
        {
            this.SetDDLData();
            this.ScheduleData();
        }

        Page.DataBind();
    }

    private void SetDDLData()
    {
        int iYearCnt = 0;
        int iCnt = 0;

        iYearCnt = DateTime.Now.Year;

        for (int i = iYearCnt - 5; i < iYearCnt + 5; i++)
        {
            ListItem li = new ListItem(i.ToString(), i.ToString());
            ddlYear.Items.Add(li);
        }

        for (int i = 1; i <= 12; i++)
        {
            ListItem li = new ListItem(i.ToString(), i.ToString());
            ddlMonth.Items.Add(li);
        }

        iCnt = ddlYear.Items.Count;
        for (int i = 0; i < iCnt; i++)
        {
            if (ddlYear.Items[i].Value == strYear)
            {
                ddlYear.Items[i].Selected = true;
                break;
            }
        }

        iCnt = ddlMonth.Items.Count;
        for (int i = 0; i < iCnt; i++)
        {
            if (ddlMonth.Items[i].Value == strMonth)
            {
                ddlMonth.Items[i].Selected = true;
                break;
            }
        }
    }

    #region 일정 데이터
    /// <summary>
    /// 일정 데이터
    /// </summary>
    private void ScheduleData()
    {
        OleDbConnection Con = new OleDbConnection(strCon);
        OleDbCommand Cmd = new OleDbCommand();
        OleDbParameter sParams = new OleDbParameter();
        OleDbDataAdapter Adap;
        DataSet ds = new DataSet();
        DataTable dt = new DataTable();

        try
        {
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("../Default.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prPubMonthSchedule";

            // 도메인
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;
            // 양력 일정 날짜(년)
            sParams = Cmd.Parameters.Add("@chrSolYear", OleDbType.Char, 4);
            sParams.Direction = ParameterDirection.Input;
            // 양력 일정 날짜(월)
            sParams = Cmd.Parameters.Add("@chrSolMonth", OleDbType.Char, 2);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@chrSolYear"].Value = strYear;
            Cmd.Parameters["@chrSolMonth"].Value = WF.StrPlus(strMonth, 2, "0");

            Adap = new OleDbDataAdapter(Cmd);

            Adap.Fill(ds, "SCHEDULE");
            dt = ds.Tables["SCHEDULE"];

            foreach (DataRow dr in dt.Rows)
            {
                int iDay = int.Parse(dr["SOL_DAY"].ToString());

                // 일정제목에 링크를 건다.
                arrScheduleData[iDay] += "<a href=\"javascript: ViewSchedule('" + strYear + "', '" +
                    strMonth + "', '" + iDay.ToString() + "', '" + dr["SCH_NO"].ToString().Trim() + "', '" +
                    dr["SCH_PUBLIC"].ToString() + "');\">" + WF.StrCut(dr["SCH_TITLE"].ToString(), 6, "..") + "</a>|";
            }
        }
        catch (Exception err)
        {
            WF.WriteMessage(strYear + "년 " + strMonth + "월 일정을 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("../Default.aspx");
            return;
        }
    }
    #endregion

    protected void DayRender(object sender, DayRenderEventArgs e)
    {
        if (!e.Day.IsOtherMonth)
        {
            DateTime dt = e.Day.Date;
            string strMonth = WF.StrPlus(dt.Month.ToString(), 2, "0");
            string strDay = WF.StrPlus(dt.Day.ToString(), 2, "0");
            string strDayColor = "";
            Literal l = new Literal();

            try
            {
                if (arrScheduleData[dt.Day].Length > 0)
                {
                    if (arrScheduleData[dt.Day].Substring(arrScheduleData[dt.Day].Length - 1, 1) == "|")
                        arrScheduleData[dt.Day] = arrScheduleData[dt.Day].Substring(0, arrScheduleData[dt.Day].Length - 1);

                    arrScheduleData[dt.Day] = arrScheduleData[dt.Day].Substring(0, arrScheduleData[dt.Day].Length - 1).Replace("|", "<br>");
                }
                else
                    arrScheduleData[dt.Day] = "&nbsp;";

                e.Cell.Controls.Clear();

                if (e.Day.Date.DayOfWeek == DayOfWeek.Saturday)
                    strDayColor = "blue";
                else if (e.Day.Date.DayOfWeek == DayOfWeek.Sunday)
                {
                    strDayColor = "red";
                    //e.Cell.BackColor = System.Drawing.Color.AntiqueWhite;
                }
                else
                    strDayColor = "black";

                //if (strDayColor == "red")
                //e.Cell.BackColor = System.Drawing.Color.AntiqueWhite;

                l.Text = "<font color=\"" + strDayColor + "\"><a href=\"javascript: ViewSchedule('" + dt.Year + "', '" + dt.Month + "', '" + dt.Day + "', '');\">" +
                    "" + dt.Day.ToString() + "</a><br>" + arrScheduleData[dt.Day] + "</font>";

                e.Cell.Controls.Add(l);
                Style s = new Style();
                s.Height = 70;
                e.Cell.ApplyStyle(s);

                if (e.Day.IsSelected)
                    e.Cell.BackColor = System.Drawing.Color.LightCyan;
            }
            catch (Exception err)
            {
                WF.WriteMessage("일정을 출력하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "오류 발생 일자: " + dt.Year + "년 " + dt.Month + "월 " + dt.Day + "일\\r\\n\\r\\n" +
                    "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
                return;
            }
        }
        else
        {
            // 날짜에 해당하는 Cell 컨트롤 설정값을 초기화 한다.
            e.Cell.Controls.Clear();

            if (e.Day.Date.DayOfWeek == DayOfWeek.Sunday)
            {
                //e.Cell.BackColor = System.Drawing.Color.AntiqueWhite;
            }

            Literal l = new Literal();
            Style s = new Style();

            l.Text = "<font color=\"gray\">" + e.Day.Date.Day.ToString() + "</font>";
            s.Height = 70;
            e.Cell.Controls.Add(l);
            e.Cell.ApplyStyle(s);
        }
    }

    protected void Calendar_VisibleMonthChanged(object sender, System.Web.UI.WebControls.MonthChangedEventArgs e)
    {
        string strYear = e.NewDate.Year.ToString();
        string strMonth = e.NewDate.Month.ToString();
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }

    protected void Calendar_SelectionChanged(object sender, EventArgs e)
    {
        DateTime dt = Calendar.SelectedDate;
        string strMonth = WF.StrPlus(dt.Month.ToString(), 2, "0");
        string strDay = WF.StrPlus(dt.Day.ToString(), 2, "0");

        Response.Redirect("DaySchedule.aspx?strYear=" + dt.Year + "&strMonth=" + strMonth + "&strDay=" + strDay);
    }

    protected void ddlYear_SelectedIndexChanged(object sender, EventArgs e)
    {
        string strYear = ddlYear.SelectedValue;
        string strMonth = ddlMonth.SelectedValue;
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }

    protected void ddlMonth_SelectedIndexChanged(object sender, EventArgs e)
    {
        string strYear = ddlYear.SelectedValue;
        string strMonth = ddlMonth.SelectedValue;
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }
}
