﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.IO;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

/// <summary>
/// BoardInfo의 요약 설명입니다.
/// </summary>
public class BoardInfo
{
    private int iBrdNo = 0;
    private string strUserId = "";
    private string strBrdPos = "";
    private string strCon = System.Configuration.ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strErrMsg = "";

    private int iBrdViewNo = 0;
    private string strBrdName = "";
    private int iBrdDocCnt = 0;
    private int iBrdListCnt = 0;
    private bool bIsAttach = false;
    private string strBrdHeader = "";
    private string strBrdFooter = "";
    private string strBrdAuthList = "";
    private string strBrdAuthRead = "";
    private string strBrdAuthWrite = "";
    private string strBrdAuthModify = "";
    private string strBrdAuthDelete = "";
    private string strBrdAuthReply = "";
    private string strBrdAdminId = "";

    private UserInfo UI;

    #region 개체 인스턴스 생성자
    /// <summary>
    /// 개체 인스턴스 생성자
    /// </summary>
    public BoardInfo()
    {
        //
        // TODO: 여기에 생성자 논리를 추가합니다.
        //
    }

    public BoardInfo(int intBrdNo, string sUserId, string sDomain, string strBoardPos)
    {
        if (intBrdNo <= 0)
        {
            this.strErrMsg = "게시판 번호는 음수로 설정되면 안됩니다.";
            return;
        }

        strDomain = sDomain;

        UI = new UserInfo(sUserId, strDomain, strCon);

        this.BoardNo = intBrdNo;
        this.UserId = sUserId;
        this.BoardPos = strBoardPos;

        this.ProcBoardInfo();
    }
    #endregion

    #region DB에서 해당 게시판 정보를 가져온다.
    /// <summary>
    /// DB에서 해당 게시판 정보를 가져온다.
    /// </summary>
    private void ProcBoardInfo()
    {
        OleDbConnection Con = new OleDbConnection(strCon);
        OleDbDataAdapter Adap = null;
        OleDbCommand Cmd = new OleDbCommand();
        OleDbParameter sParams = new OleDbParameter();
        DataSet ds = new DataSet();
        DataTable dt = new DataTable();

        try
        {
            Con.Open();
        }
        catch (Exception err)
        {
            strErrMsg = "DB Connection Failed!!!\\r\\n\\r\\n" + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prBoardInfo";

            // 실행 결과값
            sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // 게시판 번호
            sParams = Cmd.Parameters.Add("@iBrdNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 도메인 명
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@iBrdNo"].Value = iBrdNo;
            Cmd.Parameters["@varDomain"].Value = strDomain;

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "BRD_INFO");
            dt = ds.Tables["BRD_INFO"];

            int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());

            if (iValue > 0)
            {
                this.strErrMsg = iBrdNo.ToString() + " 번 게시판 정보를 가져오는 도중 오류가 발생했습니다.\\r\\n\r\\n" +
                    "SQL Error No: " + iValue.ToString();
                return;
            }

            int iRowCnt = dt.Rows.Count;

            if (iRowCnt > 1)
            {
                this.strErrMsg = iBrdNo.ToString() + " 번 게시판 정보가 하나 이상입니다.\\r\\n\\r\\n" +
                    "관리자에게 문의 하세요.";
                return;
            }
            else if (iRowCnt < 1)
            {
                this.strErrMsg = iBrdNo.ToString() + " 번 게시판 정보가 없습니다.\\r\\n\\r\\n" +
                    "관리자에게 문의 하세요.";
                return;
            }

            foreach (DataRow dr in dt.Rows)
            {
                iBrdViewNo = int.Parse(dr["brd_view_no"].ToString());
                strBrdName = dr["brd_name"].ToString();
                iBrdDocCnt = int.Parse(dr["brd_doc_cnt"].ToString());
                iBrdListCnt = int.Parse(dr["brd_list_cnt"].ToString());
                strBrdHeader = dr["brd_header"].ToString();
                strBrdFooter = dr["brd_footer"].ToString();
                strBrdAuthList = dr["brd_auth_list"].ToString();
                strBrdAuthRead = dr["brd_auth_read"].ToString();
                strBrdAuthWrite = dr["brd_auth_write"].ToString();
                strBrdAuthModify = dr["brd_auth_modify"].ToString();
                strBrdAuthDelete = dr["brd_auth_delete"].ToString();
                strBrdAuthReply = dr["brd_auth_reply"].ToString();
                strBrdAdminId = dr["brd_admin_id"].ToString();

                if (dr["brd_is_attach"].ToString().ToUpper() == "Y")
                    bIsAttach = true;

                break;
            }
        }
        catch (Exception err)
        {
            this.strErrMsg = iBrdNo.ToString() + " 번 게시판 정보를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n");
            return;
        }

        return;
    }
    #endregion

    #region 게시판/게시물 권한 체크
    /// <summary>
    /// 게시판/게시물 권한 체크
    /// </summary>
    /// <returns></returns>
    public bool BoardAuth()
    {
        bool bBoardAuth = false;
        int iUserPermit = 0;
        int iAuthVal = 0;

        strBrdPos = strBrdPos.ToUpper();

        try
        {
            iUserPermit = int.Parse(UI.UserPermit);
        }
        catch (Exception err)
        {
            this.strErrMsg = "사용자 권한 형식을 변경하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n");
            return false;
        }

        try
        {
            if (this.AdminId != this.strUserId || iUserPermit != 1)
            {
                // 게시판 접근 권한
                if (strBrdPos == "LS")
                {
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthList);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 게시판에 접근할 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else if (strBrdPos == "RD")
                {
                    // 게시물 읽기 권한
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthRead);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 게시물을 읽을 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else if (strBrdPos == "WT")
                {
                    // 게시물 쓰기 권한
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthWrite);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 게시판에 게시물을 작성할 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else if (strBrdPos == "MD")
                {
                    // 게시물 수정 권한
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthModify);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 해당 게시물을 수정할 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else if (strBrdPos == "DT")
                {
                    // 게시물 삭제 권한
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthDelete);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 해당 게시물을 삭제할 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else if (strBrdPos == "RP")
                {
                    // 게시물 답변 권한
                    // 게시판 접근 권한 값을 문자열 형식에서 숫자 형식으로 변환
                    iAuthVal = int.Parse(this.AuthReply);

                    if (iUserPermit > iAuthVal)
                        this.strErrMsg = "아이디가 " + strUserId + " 인 사용자는 해당 게시물에 답변글을 작성할 수 없습니다.";
                    else
                        bBoardAuth = true;
                }
                else
                {
                    // 정상적인 게시판/게시물 코드가 아닌 경우
                    this.strErrMsg = "게시판/게시물 권한이 올바르지 않습니다.";
                    return false;
                }
            }
            else
                bBoardAuth = true;
        }
        catch (Exception err)
        {
            this.strErrMsg = "게시판/게시물 권한을 확인하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n");
            return false;
        }

        return bBoardAuth;
    }
    #endregion

    #region 첨부파일 다운로드
    public void AttachFileDownload(System.Web.UI.Page wPage, string strBrdNo, string strAttachFile)
    {
        WebFunction WF = new WebFunction(wPage);

        string strPath = wPage.Request.MapPath("./") + "Data\\" + strBrdNo + "\\" + strAttachFile;

        if (!File.Exists(strPath))
        {
            WF.WriteMessage(strAttachFile + " 파일명을 가진 첨부파일이 해당 경로에 존재하지 않습니다.");
            return;
        }

        wPage.Response.ClearHeaders();
        wPage.Response.ClearContent();
        wPage.Response.Charset = "euc-kr";
        wPage.Response.ContentEncoding = Encoding.GetEncoding("euc-kr");
        wPage.Response.ContentType = "Application/Octet-stream";
        wPage.Response.AppendHeader("Content-Disposition", "Attachment;\tFileName=\"" + HttpUtility.UrlEncode(strAttachFile, new UTF8Encoding()) + "\"");

        FileStream fs = new FileStream(strPath, FileMode.Open, FileAccess.Read);
        byte[] buf = new byte[1024];

        while (fs.Read(buf, 0, 1024) != 0)
        {
            wPage.Response.BinaryWrite(buf);
        }

        wPage.Response.End();
    }
    #endregion

    #region 첨부파일 삭제
    /// <summary>
    /// 첨부파일 삭제
    /// </summary>
    /// <param name="wPage"></param>
    /// <param name="strBrdNo"></param>
    /// <param name="strAttachFile"></param>
    /// <returns></returns>
    public bool AttachFileDelete(System.Web.UI.Page wPage, string strBrdNo, string strAttachFile)
    {
        WebFunction WF = new WebFunction(wPage);

        string strPath = wPage.Request.MapPath("./") + "Data\\" + strBrdNo + "\\" + strAttachFile;

        try
        {
            if (File.Exists(strPath))
                File.Delete(strPath);
        }
        catch (Exception err)
        {
            WF.WriteMessage("업로드 되어 있는 첨부파일을 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            return false;
        }

        return true;
    }
    #endregion

    #region 게시판 번호를 설정한다.
    /// <summary>
    /// 게시판 번호를 설정한다.
    /// </summary>
    public int BoardNo
    {
        set { iBrdNo = value; }
    }
    #endregion

    #region 사용자 아이디를 설정한다.
    /// <summary>
    /// 사용자 아이디를 설정한다.
    /// </summary>
    public string UserId
    {
        set { strUserId = value; }
    }
    #endregion

    #region 게시판 위치를 설정한다.
    /// <summary>
    /// 게시판 위치를 설정한다.
    /// </summary>
    private string BoardPos
    {
        set { strBrdPos = value; }
    }
    #endregion

    #region 에러 메세지를 가져온다.
    /// <summary>
    /// 에러 메세지를 가져온다.
    /// </summary>
    public string ErrMsg
    {
        get { return strErrMsg; }
    }
    #endregion

    #region 게시판 번호
    /// <summary>
    /// 게시판 번호
    /// </summary>
    public int ViewNo
    {
        get { return iBrdViewNo; }
    }
    #endregion

    #region 게시판 이름
    /// <summary>
    /// 게시판 이름
    /// </summary>
    public string BoardName
    {
        get { return strBrdName; }
    }
    #endregion

    #region 게시물 출력 갯수
    /// <summary>
    /// 게시물 출력 갯수
    /// </summary>
    public int DocCount
    {
        get { return iBrdDocCnt; }
    }
    #endregion

    #region 게시판 페이지 이동 출력 갯수
    /// <summary>
    /// 게시판 페이지 이동 출력 갯수
    /// </summary>
    public int ListCount
    {
        get { return iBrdListCnt; }
    }
    #endregion

    #region 첨부파일 사용여부
    /// <summary>
    /// 첨부파일 사용여부
    /// </summary>
    public bool IsAttach
    {
        get { return bIsAttach; }
    }
    #endregion

    #region 게시판 머릿글
    /// <summary>
    /// 게시판 머릿글
    /// </summary>
    public string Header
    {
        get { return strBrdHeader; }
    }
    #endregion

    #region 게시판 꼬릿글
    /// <summary>
    /// 게시판 꼬릿글
    /// </summary>
    public string Footer
    {
        get { return strBrdFooter; }
    }
    #endregion

    #region 게시판 접근권한
    /// <summary>
    /// 게시판 접근권한
    /// </summary>
    public string AuthList
    {
        get { return strBrdAuthList; }
    }
    #endregion

    #region 게시물 읽기권한
    /// <summary>
    /// 게시물 읽기권한
    /// </summary>
    public string AuthRead
    {
        get { return strBrdAuthRead; }
    }
    #endregion

    #region 게시물 쓰기권한
    public string AuthWrite
    {
        get { return strBrdAuthWrite; }
    }
    #endregion

    #region 게시물 수정권한
    /// <summary>
    /// 게시물 수정권한
    /// </summary>
    public string AuthModify
    {
        get { return strBrdAuthModify; }
    }
    #endregion

    #region 게시물 삭제권한
    /// <summary>
    /// 게시물 삭제권한
    /// </summary>
    public string AuthDelete
    {
        get { return strBrdAuthDelete; }
    }
    #endregion

    #region 게시물 답장쓰기 권한
    /// <summary>
    /// 게시물 답장쓰기 권한
    /// </summary>
    public string AuthReply
    {
        get { return strBrdAuthReply; }
    }
    #endregion

    #region 게시판 관리자 아이디
    public string AdminId
    {
        get { return strBrdAdminId; }
    }
    #endregion
}
