﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class Board_ListDoc : System.Web.UI.Page
{
    protected string strBrdName = "";
    protected string strHeader = "";
    protected string strFooter = "";
    protected string strPageLink = "";
    protected string strBrdNo = "";
    protected string strPage = "";

    private WebFunction WF;
    private UserInfo UI;
    private BoardInfo BI;
    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private int iBrdNo = 0;
    private int iPage = 0;
    private string strSchType = "";
    private string strSchValue = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../log/login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strBrdNo = Request.Params["brdNo"];
        iBrdNo = int.Parse(strBrdNo);

        UI = new UserInfo(Session["USER_ID"].ToString(), strDomain, strCon);
        BI = new BoardInfo(iBrdNo, Session["USER_ID"].ToString(), strDomain, "LS");

        strBrdName = BI.BoardName;

        if (!Page.IsPostBack)
        {
            // 게시판 객체 에러 체크
            if (BI.ErrMsg != "")
            {
                WF.WriteMessage(BI.ErrMsg);
                WF.MovePage("../Mail/Main.aspx");
                return;
            }

            // 게시판 권한 체크
            if (!BI.BoardAuth())
            {
                WF.WriteMessage(BI.ErrMsg);
                WF.MovePage("../Mail/Main.aspx");
                return;
            }

            iPage = WF.StringToInt(Request.Params["iPage"], 1);
            strSchType = WF.StringDefaultValue(Request.Params["schType"], "");
            strSchValue = WF.StringDefaultValue(Request.Params["schValue"], "");

            this.DocListBind();
            strHeader = BI.Header;
            strFooter = BI.Footer;
        }
        string strScript = "if (!Serach()) return false; else return true;";
        ibSearch.Attributes.Add("onclick", strScript);

        Page.DataBind();
    }

    #region 게시물 리스트
    /// <summary>
    /// 게시물 리스트
    /// </summary>
    private void DocListBind()
    {
        int iTotCnt = 0;
        OleDbConnection Con = new OleDbConnection(strCon);
        OleDbDataAdapter Adap;
        OleDbCommand Cmd = new OleDbCommand();
        OleDbParameter sParams = new OleDbParameter();
        DataSet ds = new DataSet();
        DataTable dt = new DataTable();

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListDoc";

            // 현재 페이지
            sParams = Cmd.Parameters.Add("@iPage", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 출력 게시물수
            sParams = Cmd.Parameters.Add("@iPageSize", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 게시판 번호
            sParams = Cmd.Parameters.Add("@iBrdNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 도메인 명
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // 검색 형식
            sParams = Cmd.Parameters.Add("@varSchType", OleDbType.Char, strSchType.Length);
            sParams.Direction = ParameterDirection.Input;

            // 검색어
            sParams = Cmd.Parameters.Add("@varSchVal", OleDbType.VarWChar, strSchValue.Length);
            sParams.Direction = ParameterDirection.Input;


            // 리턴 값
            sParams = Cmd.Parameters.Add("@iTotCnt", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Output;
            // 전체 게시물 수 

            Cmd.Parameters["@iPage"].Value = iPage;
            Cmd.Parameters["@iPageSize"].Value = BI.DocCount;
            Cmd.Parameters["@iBrdNo"].Value = iBrdNo;
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@varSchType"].Value = strSchType;
            Cmd.Parameters["@varSchVal"].Value = strSchValue;

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "DOC_INFO");
            dt = ds.Tables["DOC_INFO"];

            int iRowCnt = dt.Rows.Count;
            int iCnt = 0;
            string[,] arrDocInfo = new string[iRowCnt, 8];

            foreach (DataRow dr in dt.Rows)
            {
                arrDocInfo[iCnt, 0] = dr["DOC_NO"].ToString();				// 게시물 번호
                arrDocInfo[iCnt, 1] = dr["USER_NAME"].ToString();			// 사용자 이름
                arrDocInfo[iCnt, 2] = dr["DOC_SUBJECT"].ToString();			// 제목
                arrDocInfo[iCnt, 3] = dr["DOC_WRITE_DATE"].ToString();		// 작성일자
                arrDocInfo[iCnt, 4] = dr["DOC_READ_CNT"].ToString();		// 조회수
                arrDocInfo[iCnt, 5] = dr["DOC_VIEW_NO"].ToString();			// 게시물 출력 번호
                arrDocInfo[iCnt, 6] = dr["DOC_STEP"].ToString();			// 게시물 깊이
                arrDocInfo[iCnt, 7] = dr["EMAIL"].ToString();				// 메일주소
                ++iCnt;
            }

            dt.Clear();
            dt.Columns.Remove("DOC_VIEW_NO");

            dt.Columns.Add("DOC_VIEW_NO", System.Type.GetType("System.String"));


            for (int iLoop = 0; iLoop < iRowCnt; iLoop++)
            {
                int iStep = 0;
                DataRow dr = dt.NewRow();

                iStep = int.Parse(arrDocInfo[iLoop, 6]);

                dr["DOC_NO"] = arrDocInfo[iLoop, 0];
                dr["USER_NAME"] = arrDocInfo[iLoop, 1];
                dr["DOC_WRITE_DATE"] = arrDocInfo[iLoop, 3];
                dr["DOC_READ_CNT"] = arrDocInfo[iLoop, 4];

                // 게시물 출력 번호
                if (int.Parse(arrDocInfo[iLoop, 5]) == 0)
                    dr["DOC_VIEW_NO"] = "&nbsp;";
                else
                    dr["DOC_VIEW_NO"] = arrDocInfo[iLoop, 5];

                // 제목에 게시물 보기 링크 걸기
                arrDocInfo[iLoop, 2] = "<a href=\"ViewDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + arrDocInfo[iLoop, 0] +
                    "&page=" + strPage + "\">" + arrDocInfo[iLoop, 2] + "</a>";

                // 답변 게시물일 경우에 제목 앞에 공백을 넣어준다.
                if (iStep > 0)
                {
                    for (int i = 0; i < iStep; i++)
                        arrDocInfo[iLoop, 2] = "&nbsp;&nbsp;" + arrDocInfo[iLoop, 2];

                    dr["DOC_SUBJECT"] = arrDocInfo[iLoop, 2];
                }
                else
                    dr["DOC_SUBJECT"] = arrDocInfo[iLoop, 2];

                dr["EMAIL"] = arrDocInfo[iLoop, 7];

                dt.Rows.Add(dr);
            }

            // 전체 게시물 수
            iTotCnt = int.Parse(Cmd.Parameters["@iTotCnt"].Value.ToString());
        }
        catch (Exception err)
        {
            WF.WriteMessage("게시물 리스트를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            return;
        }

        int iTotPage = 0;

        iTotPage = iTotCnt / BI.DocCount;

        if ((iTotCnt % BI.DocCount) > 0)
            iTotPage++;

        if (iTotPage <= 0)
            iTotPage++;

        rptListDoc.DataSource = dt.DefaultView;
        rptListDoc.DataBind();

        strPageLink = WF.PageLink(iTotPage, iPage, "ListDoc.aspx", "&brdNo=" + strBrdNo + "&schType=" + strSchType +
            "&schValue=" + strSchValue, BI.DocCount, "", "", "", "");
    }
    #endregion

    protected void ibSearch_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        // 검색 형식 초기화
        strSchType = "";
        // 검색어 초기화
        strSchValue = "";

        strSchType = ddlSchType.SelectedValue;
        strSchValue = txtSchValue.Text;

        if (strSchValue == "")
        {
            WF.WriteMessage("검색어를 입력해 주세요.");
            WF.HistoryBack();
            return;
        }

        Response.Redirect("ListDoc.aspx?brdNo=" + strBrdNo + "&schType=" + strSchType +
            "&schValue=" + strSchValue);
        return;
    }
}
