﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;
using Passkorea.MailParse;
using Passkorea.MIME;

public partial class Board_ReplyDoc : System.Web.UI.Page
{
    // 게시판 정보
    protected string strBrdName = "";
    protected string strHeader = "";
    protected string strFooter = "";
    protected string strPageLink = "";
    protected string strBrdNo = "";
    protected string strPage = "";
    protected string strDocNo = "";

    // 게시물 관련 전역 변수
    protected string strSubject = "";
    protected string strReadCnt = "";
    protected string strWriterName = "";
    protected string strEmail = "";
    protected string strRecomCnt = "";
    protected string strContent = "";
    protected string strAttachFile = "";
    protected long iAttachSize = 0;

    private OleDbConnection Con;
    private OleDbTransaction Trans;
    private OleDbDataAdapter Adap;
    private OleDbParameter sParams = new OleDbParameter();
    private OleDbCommand Cmd = new OleDbCommand();
    private DataSet ds = new DataSet();
    private DataTable dt = new DataTable();
    private WebFunction WF;
    private UserInfo UI;
    private BoardInfo BI;

    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private int iBrdNo = 0;
    
    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../log/login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strBrdNo = Request.Params["brdNo"];
        strDocNo = Request.Params["docNo"];

        iBrdNo = int.Parse(strBrdNo);
        UI = new UserInfo(Session["USER_ID"].ToString(), strDomain, strCon);
        BI = new BoardInfo(iBrdNo, Session["USER_ID"].ToString(), strDomain, "RP");

        strBrdName = BI.BoardName;

        if (BI.ErrMsg != "")
        {
            WF.WriteMessage(BI.ErrMsg);
            WF.MovePage("ViewDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
            return;
        }

        if (!BI.BoardAuth())
        {
            WF.WriteMessage(BI.ErrMsg);
            WF.MovePage("ViewDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
            return;
        }

        if (!Page.IsPostBack)
        {
            this.DocInfoBind();

            if (!BI.IsAttach)
            {
                trAttach.Visible = false;
                trOldAttach.Visible = false;
            }

            strHeader = BI.Header;
            strFooter = BI.Footer;
        }

        string strScript = "if (!ReplyDoc()) return false; else return true;";
        ibReplyDoc.Attributes.Add("onclick", strScript);

        Page.DataBind();
    }

    #region 선택된 게시물을 보여준다.
    /// <summary>
    /// 선택된 게시물을 보여준다.
    /// </summary>
    private void DocInfoBind()
    {
        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ViewDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prViewDoc";

            Cmd.Parameters.Clear();

            // 실행 결과값
            sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // 게시판 번호
            sParams = Cmd.Parameters.Add("@iBrdNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 게시물 번호
            sParams = Cmd.Parameters.Add("@iDocNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 도메인 명
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@iBrdNo"].Value = iBrdNo;
            Cmd.Parameters["@iDocNo"].Value = int.Parse(strDocNo);
            Cmd.Parameters["@varDomain"].Value = strDomain;

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "DOC_INFO");
            dt = ds.Tables["DOC_INFO"];

            int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());

            if (iValue != 0)
            {
                WF.WriteMessage("선택한 게시물을 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "SQL Error Number: " + iValue.ToString());
                WF.MovePage("ListDoc.aspx?brdNo=" + strBrdNo + "&page=" + strPage);
                return;
            }

            int iRowCnt = dt.Rows.Count;

            if (iRowCnt <= 0)
            {
                WF.WriteMessage("선택한 게시물이 존재하지 않습니다.");
                WF.MovePage("ListDoc.aspx?brdNo=" + strBrdNo + "&page=" + strPage);
                return;
            }
            else if (iRowCnt == 1)
            {
                DataRow dr = dt.Rows[0];

                strSubject = dr["DOC_SUBJECT"].ToString();
                strReadCnt = dr["DOC_READ_CNT"].ToString();
                strWriterName = dr["USER_NAME"].ToString();
                strEmail = dr["EMAIL"].ToString();
                strRecomCnt = dr["DOC_RECOM_CNT"].ToString();
                strContent = dr["DOC_CONTENT"].ToString();

                if (BI.IsAttach)
                {
                    trAttach.Visible = true;
                    strAttachFile = dr["DOC_ATTACH_FILE"].ToString();

                    if (strAttachFile.Trim() != "")
                        strAttachFile += "<br>";
                }
                else
                    trAttach.Visible = false;
            }
            else
            {
                WF.WriteMessage("선택한 게시물이 존재하지 않습니다.");
                WF.MovePage("ListDoc.aspx?brdNo=" + strBrdNo);
            }
        }
        catch (Exception err)
        {
            Con.Close();
            WF.WriteMessage("선택한 게시물을 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ListDoc.aspx?brdNo=" + strBrdNo + "&page=" + strPage);
            return;
        }
        finally
        {
            Con.Close();
            dt.Clear();
        }
    }
    #endregion

    #region 게시물 답변버튼
    /// <summary>
    /// 게시물 답변버튼
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibReplyDoc_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        string strSubject = tbSubject.Text;
        string strContent = tbContent.Text;
        string strWriterId = Session["USER_ID"].ToString();
        string strRemoteIp = Request.UserHostAddress;

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
            Trans = Con.BeginTransaction();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ReplyDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
            return;
        }

        if (BI.IsAttach)
        {
            if (!AttachFile())
            {
                WF.WriteMessage("첨부파일이 업로드되지 않았습니다.\\r\\n\\r\\n게시물 쓰기를 중지합니다.");
                WF.MovePage("ReplyDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
                return;
            }
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.Transaction = Trans;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prReplyDoc";

            Cmd.Parameters.Clear();

            // 실행 결과값
            sParams = Cmd.Parameters.Add("@iValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // 게시판번호
            sParams = Cmd.Parameters.Add("@iBrdNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 답변을 달려고 하는 게시물 번호
            sParams = Cmd.Parameters.Add("@iDocNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 도메인 명
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // 작성자 아이디
            sParams = Cmd.Parameters.Add("@varWriterId", OleDbType.VarChar, strWriterId.Length);
            sParams.Direction = ParameterDirection.Input;

            // 제목
            sParams = Cmd.Parameters.Add("@varSubject", OleDbType.VarWChar, strSubject.Length);
            sParams.Direction = ParameterDirection.Input;

            // 내용
            sParams = Cmd.Parameters.Add("@txtContent", OleDbType.LongVarWChar);
            sParams.Direction = ParameterDirection.Input;

            // 작성자 PC IP
            sParams = Cmd.Parameters.Add("@varRemoteIp", OleDbType.VarChar, strRemoteIp.Length);
            sParams.Direction = ParameterDirection.Input;

            // 첨부파일 명
            sParams = Cmd.Parameters.Add("@varAttachFile", OleDbType.VarChar, 255);
            sParams.Direction = ParameterDirection.Input;

            // 첨부파일 용량
            sParams = Cmd.Parameters.Add("@iAttachSize", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // 리턴값
            sParams = Cmd.Parameters.Add("@varRtnVal", OleDbType.VarChar, 100);
            sParams.Direction = ParameterDirection.Output;

            Cmd.Parameters["@iBrdNo"].Value = iBrdNo;
            Cmd.Parameters["@iDocNo"].Value = int.Parse(strDocNo);
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@varWriterId"].Value = strWriterId;
            Cmd.Parameters["@varSubject"].Value = strSubject;
            Cmd.Parameters["@txtContent"].Value = strContent;
            Cmd.Parameters["@varRemoteIp"].Value = strRemoteIp;
            Cmd.Parameters["@varAttachFIle"].Value = strAttachFile;
            Cmd.Parameters["@iAttachSize"].Value = iAttachSize;

            Cmd.ExecuteNonQuery();

            int iValue = int.Parse(Cmd.Parameters["@iValue"].Value.ToString());

            if (iValue < 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage("답변을 작성하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "오류 내용: " + Cmd.Parameters["@varRtnVal"].Value.ToString());
                WF.MovePage("ReplyDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
                return;
            }
            else if (iValue != 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage("답변을 작성하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "SQL Error Number: " + Cmd.Parameters["@iValue"].Value.ToString());
                WF.MovePage("ReplyDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
                return;
            }
            Trans.Commit();
        }
        catch (Exception err)
        {
            Trans.Rollback();
            Con.Close();
            WF.WriteMessage("답변을 작성하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.ToString().Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ReplyDoc.aspx?brdNo=" + strBrdNo + "&docNo=" + strDocNo);
            return;
        }
        finally
        {
            Con.Close();
        }

        WF.WriteMessage("답변이 등록되었습니다.");
        WF.MovePage("ListDoc.aspx?brdNo=" + strBrdNo);
        return;
    }
    #endregion

    #region 첨부파일 업로드
    /// <summary>
    /// 첨부파일 업로드
    /// </summary>
    /// <returns></returns>
    private bool AttachFile()
    {
        // 첨부파일이 업로드될 경로를 가져온다.
        string strSavePath = Request.MapPath("./") + "\\Data\\" + strBrdNo;

        // 현재 게시판이 첨부파일 사용인 상태인데
        // 업로드될 경로가 존재하지 않으면 경로를 생성한다.
        if (BI.IsAttach && !Directory.Exists(strSavePath))
            Directory.CreateDirectory(strSavePath);

        // 첨부파일 객체가 null이 아니면 파일을 업로드 한다.
        if (txtAttachFile.PostedFile != null)
        {
            // 클라이언트에 있는 첨부파일 전체 경로를 가져온다.
            strAttachFile = txtAttachFile.Value;

            // 값이 있으면 서버에 업로드한다.
            if (strAttachFile != "")
            {
                // 첨부파일명
                strAttachFile = Path.GetFileName(strAttachFile);
                // 첨부파일을 서버에 업로드
                txtAttachFile.PostedFile.SaveAs(strSavePath + "\\" + strAttachFile);

                // 업로드한 파일에 대한 파일 객체를 생성한다.
                // 이렇게 하는 이유는 첨부파일 용량을 가져오기 위해서 이다.
                FileInfo fi = new FileInfo(strSavePath + "\\" + strAttachFile);
                // 첨부파일 용량
                iAttachSize = fi.Length;

                return true;
            }
            else
                return true;
        }
        else
            return false;
    }
    #endregion
}
