﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class Config_Filtering_ListFiltering : System.Web.UI.Page
{
    private OleDbConnection Con;
    private OleDbTransaction Trans;
    private OleDbDataAdapter Adap;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter sParams = new OleDbParameter();
    private DataSet ds = new DataSet();
    private DataTable dt = new DataTable();

    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strUserId = "";
    private WebFunction WF;

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../../log/login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strUserId = Session["USER_ID"].ToString();

        if (!Page.IsPostBack)
        {
            this.FilterDataBind();
        }
    }

    #region 필터 데이터 바인드
    /// <summary>
    /// 필터 데이터 바인드
    /// </summary>
    private void FilterDataBind()
    {
        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("Config.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListUserFiltering";

            Cmd.Parameters.Clear();

            // 사용자 아이디
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;
            // 도메인
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@varUserId"].Value = strUserId;
            Cmd.Parameters["@varDomain"].Value = strDomain;

            Adap = new OleDbDataAdapter(Cmd);

            Adap.Fill(ds, "FILTER");
            dt = ds.Tables["FILTER"];

            int iRowCount = dt.Rows.Count;
            int iCount = 0;
            string[,] arrFilter = new string[iRowCount, 5];

            foreach (DataRow dr in dt.Rows)
            {
                string strTmp = dr["M_MAILBOX_NAME"].ToString();
                string strUse = dr["F_IS_USE"].ToString();

                if (strTmp == "")
                {
                    if (dr["F_MAILBOX"].ToString() == "inbox")
                        strTmp = "받은편지함";
                    else if (dr["F_MAILBOX"].ToString() == "outbox")
                        strTmp = "보낸편지함";
                    else if (dr["F_MAILBOX"].ToString() == "delbox")
                        strTmp = "휴지통";
                    else if (dr["F_MAILBOX"].ToString() == "delete")
                        strTmp = "삭제";
                    else
                        strTmp = "편지함없음";
                }

                if (strUse == "N")
                    strUse = "사용안함";
                else if (strUse == "Y")
                    strUse = "사용";

                arrFilter[iCount, 0] = dr["FILTER_NO"].ToString();
                arrFilter[iCount, 1] = dr["F_WORDS"].ToString();
                arrFilter[iCount, 2] = dr["F_TARGET"].ToString();
                arrFilter[iCount, 3] = strTmp;
                arrFilter[iCount, 4] = strUse;
                ++iCount;
            }

            dt.Clear();
            dt.Columns.Add("FILTER_IDX", System.Type.GetType("System.Int32"));

            for (int iLoop = 0; iLoop < iRowCount; iLoop++)
            {
                DataRow dr = dt.NewRow();
                dr["FILTER_IDX"] = iLoop + 1;
                dr["FILTER_NO"] = arrFilter[iLoop, 0];
                dr["F_WORDS"] = arrFilter[iLoop, 1];
                dr["F_TARGET"] = arrFilter[iLoop, 2];
                dr["F_MAILBOX"] = arrFilter[iLoop, 3];
                dr["F_IS_USE"] = arrFilter[iLoop, 4];
                dt.Rows.Add(dr);
            }
            rptMailFilter.DataSource = dt.DefaultView;
            rptMailFilter.DataBind();
        }
        catch (Exception err)
        {
            WF.WriteMessage("자동 편지분류 정보를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n"));
            WF.MovePage("Config.aspx");
            return;
        }
        finally
        {
            Con.Close();
        }
    }
    #endregion

    #region 수정페이지 이동 버튼
    /// <summary>
    /// 수정페이지 이동 버튼
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibModifyFilter_ModifyCommand(object sender, CommandEventArgs e)
    {
        string strFilterNo = e.CommandName;
        Response.Redirect("ModifyFiltering.aspx?iFilterNo=" + strFilterNo);
        return;
    }
    #endregion

    #region 필터링 삭제 버튼
    /// <summary>
    /// 필터링 삭제 버튼
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ibDeleteFilter_DeleteCommand(object sender, CommandEventArgs e)
    {
        string strFilterNo = e.CommandName;

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
            Trans = Con.BeginTransaction();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.MovePage("ListFiltering.aspx");
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.Transaction = Trans;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prDeleteFilter";

            Cmd.Parameters.Clear();

            // Command Parameter (Execute Return Value)
            sParams = Cmd.Parameters.Add("@iRtnValue", OleDbType.Integer);
            sParams.Direction = ParameterDirection.ReturnValue;

            // Command Parameter (Filter No)
            sParams = Cmd.Parameters.Add("@iFilterNo", OleDbType.Integer);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (User Id)
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Domain)
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;

            // Command Parameter (Output Value)
            sParams = Cmd.Parameters.Add("@varRtnVal", OleDbType.VarChar, 100);
            sParams.Direction = ParameterDirection.Output;

            Cmd.Parameters["@iFilterNo"].Value = int.Parse(strFilterNo);
            Cmd.Parameters["@varUserId"].Value = strUserId;
            Cmd.Parameters["@varDomain"].Value = strDomain;

            Cmd.ExecuteNonQuery();

            int iValue = int.Parse(Cmd.Parameters["@iRtnValue"].Value.ToString());

            if (iValue < 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage("편지 자동분류를 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "오류 내용: " + Cmd.Parameters["@varRtnVal"].Value.ToString().Replace("\r\n", "\\r\\n\\r\\n"));
                WF.HistoryBack();
                return;
            }
            else if (iValue != 0)
            {
                Trans.Rollback();
                Con.Close();
                WF.WriteMessage("편지 자동분류를 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                    "SQL Error Number: " + iValue.ToString());
                WF.MovePage("ListFiltering.aspx");
                return;
            }
            Trans.Commit();
        }
        catch (Exception err)
        {
            Trans.Rollback();
            Con.Close();

            WF.WriteMessage("선택한 편지 자동분류를 삭제하는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n"));
            WF.MovePage("ListFiltering.aspx");
            return;
        }
        finally
        {
            Con.Close();
        }

        WF.WriteMessage("선택한 자동 편지분류를 삭제했습니다.");
        WF.MovePage("ListFiltering.aspx");
    }
    #endregion
}
