﻿using System;
using System.Data;
using System.Data.OleDb;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Passkorea;

public partial class Schedule_MonthSchedule : System.Web.UI.Page
{
    protected int iNextYear;
    protected int iPrevYear;
    protected int iNextMonth;
    protected int iPrevMonth;

    private OleDbConnection Con;
    private OleDbDataAdapter Adap;
    private OleDbCommand Cmd = new OleDbCommand();
    private OleDbParameter sParams = new OleDbParameter();
    private DataTable dt = new DataTable();
    private DataSet ds = new DataSet();
    private WebFunction WF;

    private string strCon = ConfigurationSettings.AppSettings["strConnection"];
    private string strDomain = "";
    private string strUserId = "";
    private string strYear = "";
    private string strMonth = "";
    private int iYear = 0;
    private int iMonth = 0;
    private string[,] arrSchData;

    protected void Page_Load(object sender, EventArgs e)
    {
        // 여기에 사용자 코드를 배치하여 페이지를 초기화합니다.
        WF = new WebFunction(this.Page);
        WF.LoginCheck(Session["USER_ID"], "../Log/login.aspx", false);

        strDomain = Session["MAIL_DOMAIN"].ToString();
        strUserId = Session["USER_ID"].ToString();
        strYear = Request.Params["strYear"];
        strMonth = Request.Params["strMonth"];

        if ((strYear != "" && strYear != null) && (strMonth != "" && strMonth != null))
        {
            iYear = int.Parse(strYear, System.Globalization.NumberStyles.Number);
            iMonth = int.Parse(strMonth, System.Globalization.NumberStyles.Number);

            Calendar.VisibleDate = new DateTime(iYear, iMonth, 1);
        }
        else
            Calendar.SelectedDate = DateTime.Now;

        if (strYear == "" || strYear == null)
        {
            strYear = Calendar.SelectedDate.Year.ToString();
            iYear = int.Parse(strYear, System.Globalization.NumberStyles.Number);
        }

        if (strMonth == "" || strMonth == null)
        {
            strMonth = Calendar.SelectedDate.Month.ToString();
            iMonth = int.Parse(strMonth, System.Globalization.NumberStyles.Number);
        }

        if (iMonth == 12)
        {
            iNextYear = iYear + 1;
            iNextMonth = 1;
            iPrevYear = iYear;
            iPrevMonth = iMonth - 1;
        }
        else if (iMonth == 1)
        {
            iNextYear = iYear;
            iNextMonth = iMonth + 1;
            iPrevYear = iYear - 1;
            iPrevMonth = 12;
        }
        else
        {
            iNextYear = iYear;
            iNextMonth = iMonth + 1;
            iPrevYear = iYear;
            iPrevMonth = iMonth - 1;
        }

        arrSchData = new string[WF.GetLastDay(int.Parse(strYear), int.Parse(strMonth)) + 1, 2];

        for (int iLoop = 0; iLoop < arrSchData.Length / 2; iLoop++)
        {
            arrSchData[iLoop, 0] = "";
            arrSchData[iLoop, 1] = "N";
        }

        if (!Page.IsPostBack)
        {
            this.SetDDLData();
            this.SetHolidayData();
            this.ScheduleData();
        }

        Page.DataBind();
    }

    private void SetDDLData()
    {
        int iYearCnt = 0;
        int iCnt = 0;

        iYearCnt = DateTime.Now.Year;

        for (int i = iYearCnt - 5; i < iYearCnt + 5; i++)
        {
            ListItem li = new ListItem(i.ToString(), i.ToString());
            ddlYear.Items.Add(li);
        }

        for (int i = 1; i <= 12; i++)
        {
            ListItem li = new ListItem(i.ToString(), i.ToString());
            ddlMonth.Items.Add(li);
        }

        iCnt = ddlYear.Items.Count;
        for (int i = 0; i < iCnt; i++)
        {
            if (ddlYear.Items[i].Value == strYear)
            {
                ddlYear.Items[i].Selected = true;
                break;
            }
        }

        iCnt = ddlMonth.Items.Count;
        for (int i = 0; i < iCnt; i++)
        {
            if (ddlMonth.Items[i].Value == strMonth)
            {
                ddlMonth.Items[i].Selected = true;
                break;
            }
        }
    }

    #region 공휴일 데이터를 가져온다.
    /// <summary>
    /// 공휴일 데이터를 가져온다.
    /// </summary>
    private void SetHolidayData()
    {
        int iDay = 0;
        int iRestCnt = 0;

        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.HistoryBack();
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListHolidaySchedule";

            Cmd.Parameters.Clear();

            // 일정 날짜(년)
            sParams = Cmd.Parameters.Add("@chrYear", OleDbType.Char, 4);
            sParams.Direction = ParameterDirection.Input;
            // 일정 날짜(월)
            sParams = Cmd.Parameters.Add("@chrMonth", OleDbType.Char, 2);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@chrYear"].Value = strYear;
            Cmd.Parameters["@chrMonth"].Value = WF.StrPlus(strMonth, 2, "0");

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "SCHEDULE");
            dt = ds.Tables["SCHEDULE"];

            foreach (DataRow dr in dt.Rows)
            {
                // 일
                iDay = int.Parse(dr["SOLAR_DATE"].ToString().Substring(8, 2), System.Globalization.NumberStyles.Number);
                // 쉬는 일 수
                iRestCnt = int.Parse(dr["SCH_REST_CNT"].ToString(), System.Globalization.NumberStyles.Number);
                // 일정 제목
                arrSchData[iDay, 0] += "<font color=\"red\">" + WF.StrCut(dr["SCH_TITLE"].ToString(), 6, "..") + "</font>|";

                if (iRestCnt > 0)
                {
                    // 휴일이 설과 추석이면 3일을 쉰다.
                    // 이때 설과 추석 앞날과 뒷날을 쉬는 날로 한다.
                    if (iRestCnt == 3)
                    {
                        for (int iLoop = iDay - 1; iLoop <= iDay + 1; iLoop++)
                            arrSchData[iLoop, 1] = "Y";
                    }
                    // 신정 연휴면 2일을 쉰다.
                    // 이때 신정과 신정 다음날을 쉬는 날로 한다.
                    else if (iRestCnt == 2)
                    {
                        for (int iLoop = iDay; iLoop <= iDay + 1; iLoop++)
                            arrSchData[iLoop, 1] = "Y";
                    }
                    else if (iRestCnt == 1)
                        arrSchData[iDay, 1] = "Y";
                }
            }

            ds.Clear();

            Cmd.Parameters.RemoveAt("@chrYear");
            Cmd.CommandText = "prListDaysOffSchedule";

            Cmd.Parameters["@chrMonth"].Value = WF.StrPlus(strMonth, 2, "0");

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "SCHEDULE");

            dt = ds.Tables["SCHEDULE"];

            foreach (DataRow dr in dt.Rows)
            {
                iDay = int.Parse(dr["SOL_DAY"].ToString(), System.Globalization.NumberStyles.Number);
                iRestCnt = int.Parse(dr["SCH_REST_CNT"].ToString(), System.Globalization.NumberStyles.Number);
                arrSchData[iDay, 0] += "<font color=\"red\">" + WF.StrCut(dr["SCH_TITLE"].ToString(), 6, "..") + "</font>|";

                if (iRestCnt == 1)
                    arrSchData[iDay, 1] = "Y";
            }
        }
        catch (Exception err)
        {
            WF.WriteMessage(strYear + "년 " + strMonth + "월 공휴일 정보를 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            return;
        }
        finally
        {
            Con.Close();
            ds.Clear();
        }
    }
    #endregion

    #region 일정 데이터를 가져온다.
    /// <summary>
    /// 일정 데이터를 가져온다.
    /// </summary>
    private void ScheduleData()
    {
        try
        {
            Con = new OleDbConnection(strCon);
            Con.Open();
        }
        catch (Exception err)
        {
            WF.WriteMessage("DB Connection Fail!!!\\r\\n\\r\\n" +
                err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            WF.HistoryBack();
            return;
        }

        try
        {
            Cmd.Connection = Con;
            Cmd.CommandType = CommandType.StoredProcedure;
            Cmd.CommandText = "prListPSchedule";

            Cmd.Parameters.Clear();

            // 사용자 아이디
            sParams = Cmd.Parameters.Add("@varUserId", OleDbType.VarChar, strUserId.Length);
            sParams.Direction = ParameterDirection.Input;
            // 도메인
            sParams = Cmd.Parameters.Add("@varDomain", OleDbType.VarChar, strDomain.Length);
            sParams.Direction = ParameterDirection.Input;
            // 일정 날짜(년)
            sParams = Cmd.Parameters.Add("@chrYear", OleDbType.Char, 4);
            sParams.Direction = ParameterDirection.Input;
            // 일정 날짜(월)
            sParams = Cmd.Parameters.Add("@chrMonth", OleDbType.Char, 2);
            sParams.Direction = ParameterDirection.Input;

            Cmd.Parameters["@varUserId"].Value = strUserId;
            Cmd.Parameters["@varDomain"].Value = strDomain;
            Cmd.Parameters["@chrYear"].Value = strYear;
            Cmd.Parameters["@chrMonth"].Value = WF.StrPlus(strMonth, 2, "0");

            Adap = new OleDbDataAdapter(Cmd);
            Adap.Fill(ds, "SCHEDULE");
            dt = ds.Tables["SCHEDULE"];

            foreach (DataRow dr in dt.Rows)
            {
                int iDay = int.Parse(dr["SOL_DAY"].ToString());

                // 일정제목에 링크를 건다.
                arrSchData[iDay, 0] += "<a href=\"javascript: ViewSchedule('" + strYear + "', '" +
                        strMonth + "', '" + iDay.ToString() + "', '" + dr["SCH_NO"].ToString().Trim() + "', '" +
                        dr["SCH_PUBLIC"].ToString() + "');\">";

                // 공유일정 이면 일정제목을 파란색으로 보여주게 한다.
                // 단, 글자수는 6자가 넘어갈 경우 6자 까지만 보여주게 한다.
                if (dr["SCH_PUBLIC"].ToString() == "Y")
                    arrSchData[iDay, 0] += "<font color=\"blue\">" + WF.StrCut(dr["SCH_TITLE"].ToString(), 6, "..") + "</font>";
                else
                    arrSchData[iDay, 0] += WF.StrCut(dr["SCH_TITLE"].ToString(), 6, "..");

                arrSchData[iDay, 0] += "</a>|";
            }
        }
        catch (Exception err)
        {
            WF.WriteMessage(strYear + "년 " + strMonth + "월 일정을 가져오는 도중 오류가 발생했습니다.\\r\\n\\r\\n" +
                "오류 내용: " + err.Message.Replace("\\", "\\\\").Replace("\r\n", "\\r\\n\\r\\n"));
            return;
        }
        finally
        {
            Con.Close();
            ds.Clear();
        }
    }
    #endregion

    #region 해당 날짜에 데이터를 렌더링 한다.
    /// <summary>
    /// 해당 날짜에 데이터를 렌더링 한다.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void DayRender(object sender, DayRenderEventArgs e)
    {
        // 현재 월이 다른달이 아닐 경우에 데이터를 렌더링 한다.
        if (!e.Day.IsOtherMonth)
        {
            DateTime dt = e.Day.Date;			// 현재 날짜를 받아온다.
            string strMonth = WF.StrPlus(dt.Month.ToString(), 2, "0");
            string strDay = WF.StrPlus(dt.Day.ToString(), 2, "0");
            string strDayColor = "";
            Literal l = new Literal();

            // 배열에 데이터가 들어 있으면 데이터를 렌더링 한다.
            if (arrSchData[dt.Day, 0].Length > 0)
            {
                // 마지막에 붙은 문자가 |(Pipe) 문자이면 떼어낸다.
                if (arrSchData[dt.Day, 0].Substring(arrSchData[dt.Day, 0].Length - 1, 1) == "|")
                    arrSchData[dt.Day, 0] = arrSchData[dt.Day, 0].Substring(0, arrSchData[dt.Day, 0].Length - 1);

                // 내용 중간에 들어가있는 |(Pipe)문자를 <br> 태그로 변환한다.
                arrSchData[dt.Day, 0] = arrSchData[dt.Day, 0].Substring(0, arrSchData[dt.Day, 0].Length - 1).Replace("|", "<br>");
            }
            else
                arrSchData[dt.Day, 0] = "&nbsp;";

            e.Cell.Controls.Clear();

            // 현재 날짜가 토요일인 경우 날짜 글자색을 파란색으로 한다.
            if (e.Day.Date.DayOfWeek == DayOfWeek.Saturday)
            {
                if (arrSchData[dt.Day, 1] == "Y")
                    strDayColor = "red";
                else
                    strDayColor = "blue";
            }
            else if (e.Day.Date.DayOfWeek == DayOfWeek.Sunday)
            {
                // 현재 날짜가 일요일인 경우 날짜 글자색을 빨강색으로 한다.
                strDayColor = "red";
                //e.Cell.BackColor = System.Drawing.Color.AntiqueWhite;
            }
            else
            {

                if (arrSchData[dt.Day, 1] == "Y")
                {
                    // 공휴일일 경우 날짜는 빨강색으로 한다.
                    strDayColor = "red";
                }
                else
                {
                    // 그 이외에 날짜는 검정색으로 한다.
                    strDayColor = "black";
                }
            }

            // 리터럴 객체 택스트 프로퍼티에 일정 데이터를 넣는다.
            //l.Text = "<a href=\"DaySchedule.aspx?strYear=" + dt.Year + "&strMonth=" + strMonth + "&strDay=" + strDay +
            //		"\"><font color=\"" + strDayColor + "\">" + dt.Day.ToString() + "</font><br>" + arrSchData[dt.Day, 0] + "</a>";
            l.Text = "<a href=\"javascript: ViewSchedule('" + dt.Year + "', '" + dt.Month + "', '" + dt.Day +
                        "', '');\"><font color=\"" + strDayColor + "\">" + dt.Day.ToString() + "</font></a><br>" + arrSchData[dt.Day, 0] + "<br>";


            // 리터럴 객체를 DayRenderEventArgs 에 추가한다.
            e.Cell.Controls.Add(l);
            // 스타일 객체 생성
            Style s = new Style();
            // 스타일에 높이를 설정
            s.Height = 70;
            // DayRenderEventArgs 에 스타일을 업데이트 시킨다.
            e.Cell.ApplyStyle(s);

            // 해당 날짜가 오늘이면 테이블 TD에 색상을 LightCyan으로 바꾼다.
            if (e.Day.IsSelected)
                e.Cell.BackColor = System.Drawing.Color.LightCyan;
        }
        else
        {
            // 날짜에 해당하는 Cell 컨트롤 설정값을 초기화 한다.
            e.Cell.Controls.Clear();

            if (e.Day.Date.DayOfWeek == DayOfWeek.Sunday)
            {
                //e.Cell.BackColor = System.Drawing.Color.AntiqueWhite;
            }

            Literal l = new Literal();
            Style s = new Style();

            l.Text = "<font color=\"gray\">" + e.Day.Date.Day.ToString() + "</font>";
            s.Height = 70;
            e.Cell.Controls.Add(l);
            e.Cell.ApplyStyle(s);
        }
    }
    #endregion

    #region 해당 날짜를 선택하면 해당 날짜 일정 페이지로 이동한다.
    /// <summary>
    /// 해당 날짜를 선택하면 해당 날짜 일정 페이지로 이동한다.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Calendar_SelectionChanged(object sender, EventArgs e)
    {
        DateTime dt = Calendar.SelectedDate;
        string strMonth = WF.StrPlus(dt.Month.ToString(), 2, "0");
        string strDay = WF.StrPlus(dt.Day.ToString(), 2, "0");

        Response.Redirect("DaySchedule.aspx?strYear=" + dt.Year + "&strMonth=" + strMonth + "&strDay=" + strDay);
    }
    #endregion

    protected void Calendar_VisibleMonthChanged(object sender, System.Web.UI.WebControls.MonthChangedEventArgs e)
    {
        string strYear = e.NewDate.Year.ToString();
        string strMonth = e.NewDate.Month.ToString();
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }

    protected void Calendar_MonthChanged(object sender, MonthChangedEventArgs e)
    {
        string strYear = e.NewDate.Year.ToString();
        string strMonth = e.NewDate.Month.ToString();
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }

    protected void ddlYear_SelectedIndexChanged(object sender, EventArgs e)
    {
        string strYear = ddlYear.SelectedValue;
        string strMonth = ddlMonth.SelectedValue;
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }

    protected void ddlMonth_SelectedIndexChanged(object sender, EventArgs e)
    {
        string strYear = ddlYear.SelectedValue;
        string strMonth = ddlMonth.SelectedValue;
        WF.MovePage("MonthSchedule.aspx?strYear=" + strYear + "&strMonth=" + strMonth);
    }
}
